@@ -3,7 +3,8 @@ from optparse import make_option
 from django.core.management.base import BaseCommand
 from django.db import DEFAULT_DB_ALIAS
 
-from sitetree.utils import get_tree_model, get_tree_item_model, import_sitetrees
+from sitetree.utils import get_tree_model, import_project_sitetree_modules
+from sitetree.settings import APP_MODULE_NAME
 
 
 MODEL_TREE_CLASS = get_tree_model()
@@ -21,8 +22,12 @@ class Command(BaseCommand):
     def handle(self, *apps, **options):
         using = options.get('database', DEFAULT_DB_ALIAS)
 
-        trees_modules = import_sitetrees()
-        for module in trees_modules:
+        tree_modules = import_project_sitetree_modules()
+
+        if not tree_modules:
+            self.stdout.write('No sitetrees found in project apps (searched in %%app%%/%s.py).\n' % APP_MODULE_NAME)
+
+        for module in tree_modules:
             sitetrees = getattr(module, 'sitetrees', None)
             app = module.__dict__['__package__']
             if not apps or (apps and app in apps):
@@ -32,9 +37,15 @@ class Command(BaseCommand):
                         self.stdout.write('  Processing `%s` tree ...\n' % tree.alias)
                         # Delete trees with the same name beforehand.
                         MODEL_TREE_CLASS.objects.filter(alias=tree.alias).using(using).delete()
+                        # Drop id to let the DB handle it.
                         tree.id = None
                         tree.save(using=using)
                         for item in tree.dynamic_items:
                             self.stdout.write('    Adding `%s` tree item ...\n' % item.title)
+                            # Drop id to let the DB handle it.
+                            item.id = None
+                            if item.parent is not None:
+                                # Suppose parent tree object is already saved to DB.
+                                item.parent_id = item.parent.id
                             item.tree = tree
                             item.save(using=using)
