@@ -6,6 +6,7 @@ from collections import defaultdict
 from copy import copy, deepcopy
 
 from django.conf import settings
+from django import VERSION
 from django import template
 from django.core.cache import cache
 from django.db.models import signals
@@ -15,8 +16,8 @@ from django.utils.translation import get_language
 from django.template import Context
 from django.template.defaulttags import url as url_tag
 
-from .utils import DJANGO_VERSION_INT, get_tree_model, get_tree_item_model, import_app_sitetree_module, generate_id_for
-from .settings import ALIAS_TRUNK, ALIAS_THIS_CHILDREN, ALIAS_THIS_SIBLINGS, ALIAS_THIS_PARENT_SIBLINGS, ALIAS_THIS_ANCESTOR_CHILDREN
+from .utils import get_tree_model, get_tree_item_model, import_app_sitetree_module, generate_id_for
+from .settings import ALIAS_TRUNK, ALIAS_THIS_CHILDREN, ALIAS_THIS_SIBLINGS, ALIAS_THIS_PARENT_SIBLINGS, ALIAS_THIS_ANCESTOR_CHILDREN, UNRESOLVED_ITEM_MARKER
 
 
 MODEL_TREE_CLASS = get_tree_model()
@@ -188,6 +189,8 @@ def compose_dynamic_tree(src, target_tree_alias=None, parent_tree_item_alias=Non
         # Considered an application name.
         try:
             module = import_app_sitetree_module(src)
+            if module is None:
+                return None
             return result(getattr(module, 'sitetrees', None))
         except ImportError as e:
             if settings.DEBUG:
@@ -343,7 +346,6 @@ class SiteTree(object):
 
         return items
 
-
     def get_sitetree(self, alias):
         """Gets site tree items from the given site tree.
         Caches result to dictionary.
@@ -448,21 +450,13 @@ class SiteTree(object):
 
         return current_item
 
-    def url(self, sitetree_item, tag_arguments=None, context=None):
+    def url(self, sitetree_item, context=None):
         """Resolves item's URL.
 
         'sitetree_item' points to TreeItem object, 'url' property of which
             is processed as URL pattern or simple URL.
 
-        'tag_arguments' is a list of additional arguments passed to
-            'sitetree_url' in template.
-
         """
-        if tag_arguments is None:
-            tag_arguments = []
-        else:
-            # TODO Remove tag_arguments in 1.0.
-            warnings.warn('Use of sitetree_url tag additional arguments is deprecated. Feature support will be completely removed in 1.0.', DeprecationWarning)
 
         if context is None:
             context = self._global_context
@@ -472,20 +466,12 @@ class SiteTree(object):
 
         # Resolve only if item's URL is marked as pattern.
         if sitetree_item.urlaspattern:
-            resolved_var = self.resolve_var(sitetree_item.url, context)
+            url = sitetree_item.url
+            view_path = url
+            all_arguments = []
 
-            # Check whether a template variable is used instead of a URL pattern.
-            if resolved_var != sitetree_item.url:
-                if not isinstance(resolved_var, six.string_types):  # Variable contains what we're not expecting, revert to original URL.
-                    resolved_var = sitetree_item.url
-                # TODO Remove template var resolution in 1.0.
-                warnings.warn('Use of a template variable in URL field is deprecated. Feature support will be completely removed in 1.0.', DeprecationWarning)
-
-            view_path = resolved_var
-            all_arguments = copy(tag_arguments)
-
-            if ' ' in resolved_var:
-                view_path = resolved_var.split(' ')
+            if ' ' in url:
+                view_path = url.split(' ')
                 # We should try to resolve URL parameters from site tree item.
                 for view_argument in view_path[1:]:
                     resolved = self.resolve_var(view_argument)
@@ -497,7 +483,7 @@ class SiteTree(object):
                     all_arguments.append('"%s"' % str(resolved))  # We enclose arg in double quotes as already resolved.
                 view_path = view_path[0].strip('"\' ')
 
-            if DJANGO_VERSION_INT >= 150:  # "new-style" url tag - consider sitetree named urls literals.
+            if VERSION >= (1, 5, 0):  # "new-style" url tag - consider sitetree named urls literals.
                 view_path = "'%s'" % view_path
 
             url_pattern = u'%s %s' % (view_path, ' '.join(all_arguments))
@@ -522,7 +508,7 @@ class SiteTree(object):
 
                 # We make an anchor link from an unresolved URL as a reminder.
                 if not context['item.url_resolved']:
-                    resolved_url = u'#unresolved'
+                    resolved_url = UNRESOLVED_ITEM_MARKER
                 else:
                     resolved_url = context['item.url_resolved']
             else:
