@@ -1,4 +1,3 @@
-from django import VERSION
 from django.db.models import get_model
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.importlib import import_module
@@ -6,8 +5,6 @@ from django.utils.module_loading import module_has_submodule
 
 from sitetree import settings
 
-DJANGO_VERSION_INT = int('%s%s%s' % VERSION[:3])
-
 
 def generate_id_for(obj):
     """Generates and returns a unique identifier for the given object."""
@@ -66,6 +63,7 @@ def import_app_sitetree_module(app):
     except:
         if module_has_submodule(module, module_name):
             raise
+        return None
 
 
 def import_project_sitetree_modules():
@@ -73,7 +71,9 @@ def import_project_sitetree_modules():
     from django.conf import settings as django_settings
     submodules = []
     for app in django_settings.INSTALLED_APPS:
-        submodules.append(import_app_sitetree_module(app))
+        module = import_app_sitetree_module(app)
+        if module is not None:
+            submodules.append(module)
     return submodules
 
 
